summaryrefslogtreecommitdiffstats
path: root/src/gui/application/RosegardenGUIView.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
commit458efa7b0c935cbaafa2791021a5f8f7241aa876 (patch)
tree624583f2873febe23770bee3fa94b5c24bd59f4f /src/gui/application/RosegardenGUIView.h
parent747037b72944ae2c02962b7c5c96e0a7f8852e38 (diff)
downloadrosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.tar.gz
rosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.zip
Initial TQt4 port of Rosegarden
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1230242 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/application/RosegardenGUIView.h')
-rw-r--r--src/gui/application/RosegardenGUIView.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/gui/application/RosegardenGUIView.h b/src/gui/application/RosegardenGUIView.h
index 1c2e3b1..44bf12b 100644
--- a/src/gui/application/RosegardenGUIView.h
+++ b/src/gui/application/RosegardenGUIView.h
@@ -74,9 +74,10 @@ class LevelInfo;
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-class RosegardenGUIView : public QVBox
+class RosegardenGUIView : public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**p
@@ -86,7 +87,7 @@ public:
SegmentParameterBox*,
InstrumentParameterBox*,
TrackParameterBox*,
- TQWidget *parent = 0,
+ TQWidget *tqparent = 0,
const char *name=0);
/**
@@ -97,7 +98,7 @@ public:
/**
* returns a pointer to the document connected to the view
* instance. Mind that this method requires a RosegardenGUIApp
* instance as a parent widget to get to the window document
* pointer by calling the RosegardenGUIApp::getDocument() method.
*
* @see RosegardenGUIApp#getDocument
@@ -97,7 +98,7 @@ public:
* returns a pointer to the document connected to the view
* instance. Mind that this method requires a RosegardenGUIApp
- * instance as a parent widget to get to the window document
+ * instance as a tqparent widget to get to the window document
* pointer by calling the RosegardenGUIApp::getDocument() method.
*